==> hypersnapsdk_flutter-1.3.1.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHyperSnapSDK.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.content.Context;
import android.util.Log;

import com.google.gson.Gson;
import java.util.Map;
import java.util.SortedMap;
import java.util.TreeMap;

import co.hyperverge.hypersnapsdk.HyperSnapSDK;
import co.hyperverge.hypersnapsdk.model.UIConfig;
import co.hyperverge.hypersnapsdk.objects.HVSessionResponse;
import co.hyperverge.hypersnapsdk.objects.HyperSnapParams;

public class FLHyperSnapSDK {
    public void initialize(Context context, String appId, String appKey, String regionValue) {
        HyperSnapParams.Region region = HyperSnapParams.Region.valueOf(regionValue);
        HyperSnapSDK.init(context, appId, appKey, region);
    }

    public void initializeWithToken(Context context, String appId, String accessToken, String regionValue) {
        HyperSnapParams.Region region = HyperSnapParams.Region.valueOf(regionValue);
        HyperSnapSDK.initWithToken(context, appId, accessToken, region);
    }

    //    @Deprecated
    public void setHyperSnapConfig(Context context,Boolean shouldEnableSSLPinning, Boolean shouldUseSignature,
                                   Boolean shouldReturnRawResponse, Integer connectTimeout, Integer readTimeout,
                                   Integer writeTimeout, String uiConfigMap) {
        if (shouldEnableSSLPinning != null) {
            HyperSnapSDK.setShouldEnableSSLPinning(shouldEnableSSLPinning);
        }
        if (shouldUseSignature != null) {
            HyperSnapSDK.setShouldUseSignature(shouldUseSignature);
        }
        if (shouldReturnRawResponse != null) {
            HyperSnapSDK.setShouldReturnRawResponse(shouldReturnRawResponse);
        }
        if (readTimeout != null) {
            HyperSnapSDK.setHttpTimeoutValues(connectTimeout, readTimeout, writeTimeout);
        }
        if(uiConfigMap != null && !uiConfigMap.isEmpty()){
            try{
                Gson gson= new Gson();
                UIConfig uiConfig = gson.fromJson(uiConfigMap, UIConfig.class);
                HyperSnapSDK.getInstance().setUiConfig(context,uiConfig);
            }
            catch (Exception e){
                Log.e("FLHyperSnapSDK",e.getMessage());
            }
        }
    }

    public boolean startUserSession(String userID) {
        if (userID != null) {
            boolean state;
            HVSessionResponse hvSessionResponse;
            if (userID.isEmpty()) {
                hvSessionResponse = HyperSnapSDK.startUserSession();
            } else {
                hvSessionResponse = HyperSnapSDK.startUserSession(userID);
            }
            state = hvSessionResponse.isSuccess();
            return state;
        } else {
            return false;
        }
    }

    public void endUserSession() {
        HyperSnapSDK.endUserSession();
    }

    public String sortJSONKeysAlphabetically(Map<String, Object> map) {
        return HyperSnapSDK.sortJSONKeysAlphabetically((TreeMap<String, Object>) convertToTreeMap(map));
    }

    public static <K, V> SortedMap<K, V> convertToTreeMap(Map<K, V> hashMap) {
        return new TreeMap<>(hashMap);
    }

}

==> hypersnapsdk_flutter-4.10.0.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHyperSnapSDK.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.content.Context;
import android.util.Log;

import com.google.gson.Gson;

import java.util.Map;
import java.util.SortedMap;
import java.util.TreeMap;

import co.hyperverge.hypersnapsdk.HyperSnapSDK;
import co.hyperverge.hypersnapsdk.model.UIConfig;
import co.hyperverge.hypersnapsdk.objects.HVSessionResponse;
import co.hyperverge.hypersnapsdk.objects.HyperSnapParams;

public class FLHyperSnapSDK {
    private static final String TAG = "FLHyperSnapSDK";

    public void initialize(
            Context context,
            String appId,
            String appKey,
            String regionValue
    ) {
        HyperSnapParams.Region region = HyperSnapParams.Region.valueOf(regionValue);
        HyperSnapSDK.init(context, appId, appKey, region);
    }

    public void initializeWithToken(
            Context context,
            String appId,
            String accessToken,
            String regionValue
    ) {
        HyperSnapParams.Region region = HyperSnapParams.Region.valueOf(regionValue);
        HyperSnapSDK.initWithToken(context, appId, accessToken, region);
    }

    //    @Deprecated
    public void setHyperSnapConfig(
            Context context,
            Boolean shouldEnableSSLPinning,
            Boolean shouldUseSignature,
            Boolean shouldReturnRawResponse,
            Integer connectTimeout,
            Integer readTimeout,
            Integer writeTimeout,
            String uiConfigMap
    ) {
        if (shouldEnableSSLPinning != null) {
            HyperSnapSDK.setShouldEnableSSLPinning(shouldEnableSSLPinning);
        }
        if (shouldUseSignature != null) {
            HyperSnapSDK.setShouldUseSignature(shouldUseSignature);
        }
        if (shouldReturnRawResponse != null) {
            HyperSnapSDK.setShouldReturnRawResponse(shouldReturnRawResponse);
        }
        if (readTimeout != null) {
            HyperSnapSDK.setHttpTimeoutValues(connectTimeout, readTimeout, writeTimeout);
        }
        if (uiConfigMap != null && !uiConfigMap.isEmpty()) {
            try {
                Gson gson = new Gson();
                UIConfig uiConfig = gson.fromJson(uiConfigMap, UIConfig.class);
                HyperSnapSDK.getInstance().setUiConfig(context, uiConfig);
            } catch (Exception e) {
                Log.e(TAG, e.getMessage());
            }
        }
    }

    public boolean startUserSession(String userID) {
        if (userID != null) {
            boolean state;
            HVSessionResponse hvSessionResponse;
            if (userID.isEmpty()) {
                hvSessionResponse = HyperSnapSDK.startUserSession();
            } else {
                hvSessionResponse = HyperSnapSDK.startUserSession(userID);
            }
            state = hvSessionResponse.isSuccess();
            return state;
        } else {
            return false;
        }
    }

    public void endUserSession() {
        HyperSnapSDK.endUserSession();
    }

    public String sortJSONKeysAlphabetically(Map<String, Object> map) {
        return HyperSnapSDK.sortJSONKeysAlphabetically((TreeMap<String, Object>) convertToTreeMap(map));
    }

    public static <K, V> SortedMap<K, V> convertToTreeMap(Map<K, V> hashMap) {
        return new TreeMap<>(hashMap);
    }

}
